# coding: utf-8
from django.contrib.auth.backends import ModelBackend
from django.contrib.auth.models import User


class DartCMSAuthBackend(ModelBackend):
    user_model = User

    def authenticate(self, username=None, password=None, **kwargs):
        try:
            user = self.user_model.objects.get(username=username, is_active=True, is_staff=True)
            if user.check_password(password):
                return user
        except self.user_model.DoesNotExist:
            return None

    def get_user(self, user_id):
        try:
            return self.user_model.objects.get(pk=user_id)
        except self.user_model.DoesNotExist:
            return None



# coding: utf-8
from django.conf.urls import include, url
from django.utils.translation import ugettext_lazy as _

from dartcms import get_model
from dartcms.utils.config import DartCMSConfig
from dartcms.views import GridView, UpdateObjectView

from .forms import OrderForm

Order = get_model('shop', 'Order')

config = DartCMSConfig({
    'model': Order,
    'grid': {
        'grid_columns': [
            {'field': 'order_number', 'width': '10%', 'label': _('#')},
            {'field': 'date_created', 'width': '20%'},
            {'field': 'fullname', 'width': '30%'},
            {'field': 'status', 'width': '10%'},
            {'field': 'shipping_type', 'width': '10%'},
            {'field': 'payment_type', 'width': '10%'},
            {'field': 'total', 'width': '10%', 'label': _('Total')}
        ],
        'search': [
            'fullname', 'date_created'
        ],
        'base_grid_actions': ['update'],
        'additional_grid_actions': [
            {'url': 'details', 'label': _('Details')}
        ],
        'model_properties': ['order_number', 'total']
    },
    'form': {
        'form_class': OrderForm
    }
})

urlpatterns = [
    url(r'^$', GridView.as_view(**config.grid), name='index'),
    url(r'^update/(?P<pk>\d+)/$', UpdateObjectView.as_view(**config.form), name='update'),
    url(r'^(?P<children_url>details)/(?P<order>\d+)/', include('dartcms.apps.shop.order_detail.urls',
                                                               namespace='order_datails')),
]



# coding: utf-8
from django.contrib.auth.models import User
from django.db import models
from django.utils.translation import ugettext_lazy as _


class UserGroup(models.Model):
    class Meta:
        verbose_name = _('User group')
        verbose_name_plural = _('User groups')
        ordering = ['name']

    name = models.CharField(max_length=64, verbose_name=_('Group name'))
    users = models.ManyToManyField(User, related_name='user_groups')

    def __unicode__(self):
        return self.name



# coding: utf-8
from form_utils.forms import BetterModelForm

from dartcms.utils.loading import get_model


class OrderForm(BetterModelForm):
    class Meta:
        model = get_model('shop', 'Order')
        exclude = ['user']



# coding: utf-8
from django import forms
from django.contrib.auth.models import User
from django.utils.translation import ugettext_lazy as _

from dartcms.apps.modules.models import Module

from .models import UserGroup


class UserForm(forms.ModelForm):
    class Meta:
        model = User
        exclude = ('password', 'last_login', 'date_joined', 'user_permissions', 'groups')

    modules = forms.ModelMultipleChoiceField(label=_('Modules'), queryset=Module.objects.all())
    user_groups = forms.ModelMultipleChoiceField(label=_('Groups'), queryset=UserGroup.objects.all())



# -*- coding: utf-8 -*-
from django.conf.urls import url
from django.forms.models import modelform_factory

from dartcms.apps.users.models import UserGroup
from dartcms.utils.config import DartCMSConfig
from dartcms.views import (DeleteObjectView, GridView, InsertObjectView,
                           UpdateObjectView)

config = DartCMSConfig({
    'model': UserGroup,
    'grid': {
        'grid_columns': [
            {'field': 'name', 'width': '100%'},
        ]
    },
    'form': {
        'form_class': modelform_factory(model=UserGroup, exclude=['users'])
    }
})

urlpatterns = [
    url(r'^$', GridView.as_view(**config.grid), name='index'),
    url(r'^insert/$', InsertObjectView.as_view(**config.form), name='insert'),
    url(r'^update/(?P<pk>\d+)/$', UpdateObjectView.as_view(**config.form), name='update'),
    url(r'^delete/(?P<pk>\d+)/$', DeleteObjectView.as_view(**config.base), name='delete'),
]



# -*- coding: utf-8 -*-
from django.contrib.auth.forms import AdminPasswordChangeForm
from django.contrib.auth.models import User
from django.core.urlresolvers import reverse_lazy
from django.utils.translation import ugettext_lazy as _
from django.views.generic import FormView

from dartcms.views import AdminMixin, InsertObjectView, UpdateObjectView


class ChangePasswordView(AdminMixin, FormView):
    form_class = AdminPasswordChangeForm
    page_header = _('Users')
    template_name = 'dartcms/apps/users/change_password.html'
    success_url = reverse_lazy('dartcms:users:index')

    def get_form_kwargs(self):
        kwargs = super(ChangePasswordView, self).get_form_kwargs()
        kwargs['user'] = User.objects.get(pk=self.kwargs['pk'])
        return kwargs

    def get_context_data(self, *args, **kwargs):
        context = super(ChangePasswordView, self).get_context_data(**kwargs)
        context['index_url'] = reverse_lazy('dartcms:users:index')
        return context

    def form_valid(self, form):
        form.save()
        return super(ChangePasswordView, self).form_valid(form)


class SaveUserMixin(object):
    def form_valid(self, form):
        data = form.cleaned_data
        user = form.save()
        if user.id:
            user.module_set.clear()
            user.user_groups.clear()

        for module in data.get('modules', []):
            user.module_set.add(module)

        for group in data.get('user_groups', []):
            user.user_groups.add(group)

        return self.render_to_json_response({'result': True, 'action': self.action})


class CMSUserUpdateView(SaveUserMixin, UpdateObjectView):
    success_url = reverse_lazy('dartcms:users:index')
    action = 'UPDATE'

    def get_initial(self):
        obj = self.get_object()
        return {
            'modules': obj.module_set.all(),
            'user_groups': obj.user_groups.all()
        }


class CMSUserInsertView(SaveUserMixin, InsertObjectView):
    action = 'INSERT'

    def get_success_url(self):
        return reverse_lazy('dartcms:users:change_password', kwargs={'pk': self.object.pk})



# coding: utf-8
from django.conf.urls import include, url
from django.utils.translation import ugettext_lazy as _

from dartcms import get_model
from dartcms.utils.config import DartCMSConfig
from dartcms.views import (DeleteObjectView, GridView, InsertObjectView,
                           UpdateObjectView)

from .forms import ProductCatalogForm

ProductCatalog = get_model('shop', 'ProductCatalog')

config = DartCMSConfig({
    'model': ProductCatalog,
    'grid': {
        'grid_columns': [
            {'field': 'name', 'width': '50%'},
            {'field': 'slug', 'width': '40%'},
            {'field': 'is_visible', 'width': '10%'},
        ],
        'additional_grid_actions': [
            {'url': 'sections', 'label': _('Sections')}
        ]
    },
    'form': {
        'form_class': ProductCatalogForm
    }
})

urlpatterns = [
    url(r'^$', GridView.as_view(**config.grid), name='index'),
    url(r'^insert/$', InsertObjectView.as_view(**config.form), name='insert'),
    url(r'^update/(?P<pk>\d+)/$', UpdateObjectView.as_view(**config.form), name='update'),
    url(r'^delete/(?P<pk>\d+)/$', DeleteObjectView.as_view(**config.base), name='delete'),
    url(r'^(?P<children_url>sections)/(?P<catalog>\d+)/', include('dartcms.apps.shop.section.urls', namespace='sections')),
]



# coding: utf-8
from django.views.generic import TemplateView

from dartcms.apps.auth.mixins import StaffRequiredMixin


class DashboardIndexView(StaffRequiredMixin, TemplateView):
    template_name = 'dartcms/apps/dashboard/index.html'



# coding: utf-8
from django.utils.translation import ugettext_lazy as _
from form_utils.forms import BetterModelForm

from dartcms.utils.loading import get_model


class ProductCatalogForm(BetterModelForm):
    class Meta:
        model = get_model('shop', 'ProductCatalog')
        exclude = []

        fieldsets = (
            ('main', {'fields': (
                'slug',
                'name',
                'description',
            ), 'legend': _('Main')}),
            ('seo', {'fields': (
                'seo_keywords',
                'seo_description',
            ), 'legend': _('SEO')}),
            ('advanced', {'fields': (
                'image',
                'is_visible',
            ), 'legend': _('Advanced')}))



# coding: utf-8
from django.forms import DateTimeInput, ModelForm, Select, TextInput

from dartcms.apps.sitesettings.models import SiteSettings


class SiteSettingsForm(ModelForm):
    class Meta:
        model = SiteSettings
        exclude = ['slug', 'description', 'type', 'options']

    def __init__(self, *args, **kwargs):
        super(SiteSettingsForm, self).__init__(*args, **kwargs)

        label = self.instance.description

        if self.instance.type == self.instance.DATE:
            del self.fields['text_value']
            del self.fields['file_value']
            self.fields['date_value'].label = label
        elif self.instance.type == self.instance.FILE:
            del self.fields['text_value']
            del self.fields['date_value']
            self.fields['file_value'].label = label
        else:
            del self.fields['file_value']
            del self.fields['date_value']
            self.fields['text_value'].label = label
            if self.instance.type == self.instance.RICH:
                self.fields['text_value'].widget.attrs = {'class': 'rte'}
            elif self.instance.type == self.instance.TEXT:
                self.fields['text_value'].widget = TextInput()
            elif self.instance.type == self.instance.SELECT:
                options = [(o, o) for o in self.instance.options.split(";")]
                self.fields['text_value'].widget = Select(choices=options)



from django import forms
from django.db.models import TextField


class RteField(TextField):
    def formfield(self, **kwargs):
        defaults = {'max_length': self.max_length, 'widget': forms.Textarea(attrs={'rows': 20, 'class': 'rte'})}
        defaults.update(kwargs)
        return super(RteField, self).formfield(**defaults)



# coding: utf-8
from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _


class ModulesConfig(AppConfig):
    name = 'dartcms.apps.modules'
    verbose_name = _('DartCMS Modules')



# coding: utf-8
from django.utils.translation import ugettext as _

from .db import get_model_field_label, get_model_field_type


class DartCMSConfig(object):
    config = {}

    default_action_label = _('View Records')
    default_action_icon = 'next'

    def __init__(self, config):
        self.config = config

    @property
    def base(self):
        return {
            'parent_kwarg_name': self.config.get('parent_kwarg_name'),
            'parent_model_fk': self.config.get('parent_model_fk'),
            'parent_model': self.config.get('parent_model'),
            'model': self.config.get('model'),
        }

    def construct_grid_columns(self):
        model = self.config['model']
        for column in self.config['grid']['grid_columns']:
            if 'label' not in column:
                column['label'] = get_model_field_label(model, column['field'])
            if 'type' not in column:
                column['type'] = get_model_field_type(model, column['field'])

    def construct_additional_grid_actions(self):
        for action in self.config['grid']['additional_grid_actions']:
            if 'label' not in action:
                action['label'] = self.default_action_label
            if 'icon' not in action:
                action['icon'] = self.default_action_icon

    @property
    def grid(self):
        config = self.base

        if config['model']:
            if 'grid_columns' in self.config['grid']:
                self.construct_grid_columns()

        if 'additional_grid_actions' in self.config['grid']:
            self.construct_additional_grid_actions()

        config.update(self.config['grid'])
        return config

    @property
    def form(self):
        config = self.base
        if 'form' in self.config:
            config.update(self.config['form'])
        return config



# coding: utf-8
from django.conf.urls import url

from dartcms import get_model
from dartcms.utils.config import DartCMSConfig
from dartcms.views import DeleteObjectView, GridView, UpdateObjectView

from .forms import OrderDatailForm

Order = get_model('shop', 'OrderDetail')

config = DartCMSConfig({
    'model': Order,
    'parent_kwarg_name': 'order',
    'parent_model_fk': 'order_id',
    'grid': {
        'grid_columns': [
            {'field': 'name', 'width': '60%'},
            {'field': 'price', 'width': '20%'},
            {'field': 'quantity', 'width': '20%'},
        ],
        'base_grid_actions': ['update', 'delete'],
    },
    'form': {
        'form_class': OrderDatailForm
    }
})

urlpatterns = [
    url(r'^$', GridView.as_view(**config.grid), name='index'),
    url(r'^update/(?P<pk>\d+)/$', UpdateObjectView.as_view(**config.form), name='update'),
    url(r'^delete/(?P<pk>\d+)/$', DeleteObjectView.as_view(**config.base), name='delete'),
]



# -*- coding: utf-8 -*-
from django.conf.urls import url
from django.contrib.auth.models import User
from django.utils.translation import ugettext_lazy as _

from dartcms.utils.config import DartCMSConfig
from dartcms.views import DeleteObjectView, GridView
from forms import UserForm
from views import ChangePasswordView, CMSUserInsertView, CMSUserUpdateView

config = DartCMSConfig({
    'model': User,
    'grid': {
        'grid_columns': [
            {'field': 'username', 'width': '60%'},
            {'field': 'last_login', 'width': '20%'},
            {'field': 'is_staff', 'width': '10%'},
            {'field': 'is_active', 'width': '10%'},
        ],
        'additional_grid_actions': [
            {'url': 'change-password', 'label': _('Change Password'), 'icon': 'edit'}
        ],
    },
    'form': {
        'form_class': UserForm
    }
})

urlpatterns = [
    url(r'^$', GridView.as_view(**config.grid), name='index'),
    url(r'^insert/$', CMSUserInsertView.as_view(**config.form), name='insert'),
    url(r'^update/(?P<pk>\d+)/$', CMSUserUpdateView.as_view(**config.form), name='update'),
    url(r'^delete/(?P<pk>\d+)/$', DeleteObjectView.as_view(**config.base), name='delete'),
    url(r'^change-password/(?P<pk>\d+)/$', ChangePasswordView.as_view(), name='change_password'),
]



# coding: utf-8
from django.contrib.auth.models import User
from django.db import models
from django.utils.translation import ugettext_lazy as _
from jsonfield import JSONField


class ModuleGroup(models.Model):
    class Meta:
        verbose_name_plural = _('Module Groups')
        verbose_name = _('Module Group')
        ordering = ['sort']

    def __unicode__(self):
        return self.name

    slug = models.SlugField(unique=True, verbose_name=_('Slug'))
    name = models.CharField(max_length=64, verbose_name=_('Name'))
    fa = models.SlugField(verbose_name=_('FontAwesome class'))
    sort = models.IntegerField(default=1, verbose_name=_('Sort'))
    description = models.TextField(default='', verbose_name=_('Description'), blank=True)


class Module(models.Model):
    class Meta:
        verbose_name_plural = _('Modules')
        verbose_name = _('Module')
        ordering = ['group', 'sort']

    def __unicode__(self):
        return self.group.name + ' / ' + self.name

    group = models.ForeignKey(ModuleGroup, to_field='slug', verbose_name=_('Group'), related_name='modules')
    name = models.CharField(max_length=64, verbose_name=_('Name'))
    sort = models.IntegerField(default=1, verbose_name=_('Sort'))
    description = models.TextField(default='', verbose_name=_('Description'), blank=True)
    slug = models.SlugField(unique=True, verbose_name=_('Slug'))
    config = JSONField(null=True, blank=True, verbose_name=_('Config'))
    user = models.ManyToManyField(User, verbose_name=_('User'))
    is_enabled = models.BooleanField(default=True, verbose_name=_('Is Enabled'))



# coding: utf-8
from django.conf.urls import url
from django.forms import modelform_factory

from dartcms.apps.ads.models import AdPlace
from dartcms.utils.config import DartCMSConfig
from dartcms.views import GridView, UpdateObjectView

config = DartCMSConfig({
    'model': AdPlace,
    'grid': {
        'grid_columns': [
            {'field': 'name', 'width': '80%'},
            {'field': 'is_enabled', 'width': '20%'},
        ],
        'base_grid_actions': ['update']
    },
    'form': {
        'form_class': modelform_factory(AdPlace, exclude=['slug']),
    },
})

urlpatterns = [
    url(r'^$', GridView.as_view(**config.grid), name='index'),
    url(r'^update/(?P<pk>\d+)/$', UpdateObjectView.as_view(**config.form), name='update')
]



# -*- coding: utf-8 -*-
from django.conf.urls import include, url
from django.forms import modelform_factory

from dartcms.utils.config import DartCMSConfig
from dartcms.utils.loading import get_model
from dartcms.views import (DeleteObjectView, GridView, InsertObjectView,
                           UpdateObjectView)

Feed = get_model('feeds', 'Feed')

config = DartCMSConfig({
    'model': Feed,
    'grid': {
        'grid_columns': [
            {'field': 'type', 'width': '10%'},
            {'field': 'name', 'width': '90%'},
        ],
        'additional_grid_actions': [
            {'url': 'items'}
        ]
    },
    'form': {
        'form_class': modelform_factory(Feed, exclude=[]),
    }
})

urlpatterns = [
    url(r'^$', GridView.as_view(**config.grid), name='index'),
    url(r'^insert/$', InsertObjectView.as_view(**config.form), name='insert'),
    url(r'^update/(?P<pk>\d+)/$', UpdateObjectView.as_view(**config.form), name='update'),
    url(r'^delete/(?P<pk>\d+)/$', DeleteObjectView.as_view(**config.base), name='delete'),
    url(r'^(?P<children_url>items)/(?P<feed>\d+)/', include('dartcms.apps.feeds.items.urls', namespace='feed_items')),
]



# -*- coding: utf-8 -*-
from django.conf.urls import url

from dartcms.utils.config import DartCMSConfig
from dartcms.utils.loading import get_model
from dartcms.views import (DeleteObjectView, GridView, InsertObjectView,
                           UpdateObjectView)

from .forms import FeedItemForm

FeedItem = get_model('feeds', 'FeedItem')

config = DartCMSConfig({
    'model': FeedItem,
    'parent_kwarg_name': 'feed',
    'parent_model_fk': 'feed_id',
    'grid': {
        'grid_columns': [
            {'field': 'name', 'width': '60%'},
            {'field': 'is_visible', 'width': '20%'},
            {'field': 'date_published', 'width': '20%'},
        ],
        'search': [
            'name', 'date_published', 'is_visible'
        ]
    },
    'form': {
        'form_class': FeedItemForm,
    }
})

urlpatterns = [
    url(r'^$', GridView.as_view(**config.grid), name='index'),
    url(r'^insert/$', InsertObjectView.as_view(**config.form), name='insert'),
    url(r'^update/(?P<pk>\d+)/$', UpdateObjectView.as_view(**config.form), name='update'),
    url(r'^delete/(?P<pk>\d+)/$', DeleteObjectView.as_view(**config.base), name='delete'),
]



# coding: utf-8
from django.contrib import admin

from models import Module, ModuleGroup


class ModuleGroupAdmin(admin.ModelAdmin):
    pass


admin.site.register(ModuleGroup, ModuleGroupAdmin)


class ModuleAdmin(admin.ModelAdmin):
    pass


admin.site.register(Module, ModuleAdmin)
